==> opensaml-messaging-api-4.0.1-sources.jar: org/opensaml/messaging/context/navigate/ParentContextLookup.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.messaging.context.navigate;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.messaging.context.BaseContext;

import net.shibboleth.utilities.java.support.annotation.ParameterName;
import net.shibboleth.utilities.java.support.logic.Constraint;

/**
 * A {@link ContextDataLookupFunction} that gets the parent of a given context.
 * 
 * @param <StartContext> type of starting context
 * @param <ParentContext> type of the parent context
 */
public class ParentContextLookup<StartContext extends BaseContext, ParentContext extends BaseContext>
        implements ContextDataLookupFunction<StartContext, ParentContext> {
    
    /** Parent type. */
    @Nonnull private final Class<ParentContext> parentType;
    
    /**
     * Constructor.
     * 
     * @param type parent context type to look up
     */
    public ParentContextLookup(@Nonnull @ParameterName(name="type") final Class<ParentContext> type) {
        parentType = Constraint.isNotNull(type, "Parent context type cannot be null");
    }

    /** {@inheritDoc} */
    @Nullable public ParentContext apply(@Nullable final StartContext input) {

        if (input != null) {
            final BaseContext parent = input.getParent();
            if (parentType.isInstance(parent)) {
                return parentType.cast(parent);
            }
        }

        return null;
    }
    
}

==> opensaml-messaging-api-5.1.6-sources.jar: org/opensaml/messaging/context/navigate/ParentContextLookup.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.messaging.context.navigate;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;

import org.opensaml.messaging.context.BaseContext;

import net.shibboleth.shared.annotation.ParameterName;
import net.shibboleth.shared.logic.Constraint;

/**
 * A {@link ContextDataLookupFunction} that gets the parent of a given context.
 * 
 * @param <StartContext> type of starting context
 * @param <ParentContext> type of the parent context
 */
public class ParentContextLookup<StartContext extends BaseContext, ParentContext extends BaseContext>
        implements ContextDataLookupFunction<StartContext, ParentContext> {
    
    /** Parent type. */
    @Nonnull private final Class<ParentContext> parentType;
    
    /**
     * Constructor.
     * 
     * @param type parent context type to look up
     */
    public ParentContextLookup(@Nonnull @ParameterName(name="type") final Class<ParentContext> type) {
        parentType = Constraint.isNotNull(type, "Parent context type cannot be null");
    }

    /** {@inheritDoc} */
    @Nullable public ParentContext apply(@Nullable final StartContext input) {

        if (input != null) {
            final BaseContext parent = input.getParent();
            if (parentType.isInstance(parent)) {
                return parentType.cast(parent);
            }
        }

        return null;
    }
    
}
